@@ -67,6 +67,11 @@ add_np		= lambda did, doc: [ add_tag(did, doc[np.start].idx, doc[np.start].idx +
 add_ap		= lambda did, doc: [ add_tag(did,doc[ibeg].idx, doc[ibeg].idx + len(doc[ibeg:iend].text),"ap",doc[ibeg:iend].text) for name, ibeg,iend in terms.matchers['ap'](doc) ]
 add_vp		= lambda did, doc: [ add_tag(did,doc[ibeg].idx, doc[ibeg].idx + len(doc[ibeg:iend].text),"vp",doc[ibeg:iend].text) for name, ibeg,iend in terms.matchers['vp'](doc) ]
 
+@app.get('/docfts/sql')
+def feedbacks(sql:str="select * from feedbacks limit 2"):
+	''' execute sql , 2022.4.2 '''
+	return [row for row in db.conn.execute(sql).fetchall()]
+
 @app.get('/')
 def home(): 
 	return HTMLResponse(content=f"<h2>docfts,  dsk,mkf,bs, fts </h2><a href='/docs'> docs </a> | <a href='/redoc'> redoc </a><br>uvicorn docfts:app --port 80 --host 0.0.0.0 --reload <br> <br> 2022.3.20")
